@@ -11,22 +11,34 @@ readBinary <- function(file = paste0(tempdir(),"/file.bin"),
   nsetRow <- as.integer(length(index.row))
   nsetCol <- as.integer(length(index.col))
 
+  maxsetRow <- as.integer(ifelse(nsetRow>0, max(index.row), 0))
+  maxsetCol <- as.integer(ifelse(nsetCol>0, max(index.col), 0))
+
   # Read lines
-  X <- .Call("readBinFileFloat",file,nsetRow,nsetCol,
+  #dyn.load("c_utils.so")
+  X <- .Call("readBinFile", file, nsetRow, nsetCol,
+             maxsetRow, maxsetCol,
              as.integer(index.row),as.integer(index.col))
+  #dyn.unload("c_utils.so")
 
-  n <- X[[1]]; p <- X[[2]]; size <- X[[3]]
-  isFloat <- X[[4]]
-  nError <- X[[5]]
+  n <- X[[1]]
+  p <- X[[2]]
+  isfloat <- as.logical(X[[3]])
+  vartype <- X[[4]]
+  size <- X[[5]]
+  nError <- X[[6]]
 
+  type <- ifelse(vartype==1L,"integer",ifelse(vartype==2L,"logical","double"))
   if(nError == 0L){
-    if(isFloat | size==4){
-      X <- float::float32(X[[6]])
-      type <- "float"
+    if(isfloat | (type=="double" & size==4)){
+      X <- float::float32(X[[7]])
     }else{
-      X <- X[[6]]
-      type <- "double"
+      X <- X[[7]]
     }
+    if(type=="logical"){
+      storage.mode(X) <- "logical"
+    }
+    type <- ifelse(isfloat, "float32", type)
     if(verbose){
       tmp <- c(Gb=1E9,Mb=1E6,Kb=1E3,b=1E0)
       sz <- object.size(X)/tmp[min(which(object.size(X)/tmp>1))]
